@@ -40,7 +40,7 @@
 #include "pileutils.h"
 #include "patsolve/gypsysolver.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 
 Gypsy::Gypsy( const DealerInfo * di )
@@ -61,7 +61,7 @@ void Gypsy::initialize()
     talon->setLayoutPos(8.5 * dist_x + 0.4, 4 * dist_y);
     talon->setKeyboardSelectHint( KCardPile::NeverFocus );
     talon->setKeyboardDropHint( KCardPile::NeverFocus );
-    connect( talon, SIGNAL(clicked(KCard*)), SLOT(drawDealRowOrRedeal()) );
+    connect( talon, &KCardPile::clicked, this, &DealerScene::drawDealRowOrRedeal );
 
     for ( int i = 0; i < 8; ++i )
     {
@@ -184,4 +184,4 @@ public:
 } gypsyDealerInfo;
 
 
-#include "gypsy.moc"
+
